@@ -8,7 +8,7 @@ use base qw(
     DateTime::Format::Natural::Wrappers
 );
 
-our $VERSION = '1.36';
+our $VERSION = '1.35';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -50,7 +50,11 @@ sub _daytime_in_the_variant
     my ($hour) = @_;
     $hour += $opts->{hours} || 0;
     if ($self->_valid_time(hour => $hour)) {
-        $self->_set(hour => $hour);
+        $self->_set(
+            hour   => $hour,
+            minute => 0,
+            second => 0,
+        );
     }
 }
 
@@ -75,7 +79,11 @@ sub _daytime_variant
       ? $self->{Daytime}{$daytime}
       : $daytimes{$daytime};
     if ($self->_valid_time(hour => $hour)) {
-        $self->_set(hour => $hour);
+        $self->_set(
+            hour   => $hour,
+            minute => 0,
+            second => 0,
+        );
     }
 }
 
@@ -86,7 +94,11 @@ sub _daytime
     my $opts = pop;
     my ($hour) = @_;
     if ($self->_valid_time(hour => $hour)) {
-        $self->_set(hour => $hour);
+        $self->_set(
+            hour   => $hour,
+            minute => 0,
+            second => 0,
+        );
     }
 }
 
@@ -98,7 +110,10 @@ sub _hourtime_variant
     my ($value, $when) = @_;
     my $hours = $opts->{hours} || 0;
     if ($self->_valid_time(hour => $hours)) {
-        $self->_set(hour => $hours);
+        $self->_set(
+            hour   => $hours,
+            minute => 0,
+        );
         $self->_add_or_subtract({
             when  => $when,
             unit  => 'hour',
@@ -293,10 +308,38 @@ sub _at_time
     my $self = shift;
     my $opts = pop;
     my ($time) = @_;
-    my @units = qw(hour minute second);
-    my %values = map { shift @units => $_ } split /:/, $time;
-    if ($self->_valid_time(%values)) {
-        $self->_set(%values);
+    if ($time =~ /:/) {
+        my ($hour, $minute) = split /:/, $time;
+        if ($self->_valid_time(hour => $hour, minute => $minute)) {
+            $self->_set(
+                hour   => $hour,
+                minute => $minute,
+            );
+        }
+    }
+    else {
+        if ($self->_valid_time(hour => $time)) {
+            $self->_set(
+                hour   => $time,
+                minute => 0,
+            );
+        }
+    }
+}
+
+sub _time_full
+{
+    my $self = shift;
+    $self->_register_trace;
+    my $opts = pop;
+    my ($time) = @_;
+    my ($hour, $minute, $second) = split /:/, $time;
+    if ($self->_valid_time(hour => $hour, minute => $minute, second => $second)) {
+        $self->_set(
+            hour   => $hour,
+            minute => $minute,
+            second => $second,
+        );
     }
 }
 
