@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use boolean qw(true false);
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 sub _valid_date
 {
@@ -52,6 +52,26 @@ sub _valid
     }
 }
 
+sub _trace_string
+{
+    my $self = shift;
+
+    my ($trace, $modified) = map $self->{$_}, qw(trace modified);
+
+    $trace    ||= [];
+    $modified ||= {};
+
+    return undef unless (@$trace || %$modified);
+
+    my $i;
+    my %order = map { $_ => $i++ } @{$self->{data}->__units('ordered')};
+
+    return join "\n", @$trace,
+      map { my $unit = $_; "$unit: $modified->{$unit}" }
+      sort { $order{$a} <=> $order{$b} }
+      keys %$modified;
+}
+
 1;
 __END__
 
